@@ -1,9 +1,9 @@
 from django.utils.translation import ugettext_lazy as _
 
-from allianceauth.services.hooks import MenuItemHook, UrlHook
 from allianceauth import hooks
+from allianceauth.services.hooks import MenuItemHook, UrlHook
 
-from . import urls, __title__
+from . import __title__, urls
 
 
 class TimersMenuItem(MenuItemHook):
